// Copyright (C) 2021  Aravinth Manivannan <realaravinth@batsense.net>
// SPDX-FileCopyrightText: 2023 Aravinth Manivannan <realaravinth@batsense.net>
//
// SPDX-License-Identifier: AGPL-3.0-or-later

use actix_web::{http, HttpResponse, Responder};

pub use super::{context, Footer, TemplateFile, PAGES, PAYLOAD_KEY, TEMPLATES};
use crate::AppData;

mod campaigns;
mod export;

pub fn register_templates(t: &mut tera::Tera) {
    campaigns::register_templates(t);
    for template in [export::EXPORT_CAMPAIGNS].iter() {
        template.register(t).expect(template.name);
    }
}

pub mod routes {
    use super::campaigns::routes::Campaigns;
    use serde::{Deserialize, Serialize};

    #[derive(Debug, Serialize, Deserialize, PartialEq, Eq, Clone)]
    pub struct Panel {
        pub home: &'static str,
        pub export: &'static str,
        pub campaigns: Campaigns,
    }
    impl Panel {
        pub const fn new() -> Panel {
            let campaigns = Campaigns::new();
            Panel {
                home: "/",
                export: "/export",
                campaigns,
            }
        }

        pub const fn get_sitemap() -> [&'static str; 1] {
            const PANEL: Panel = Panel::new();
            [PANEL.home]
        }
    }
}

pub fn services(cfg: &mut actix_web::web::ServiceConfig) {
    cfg.service(home);
    campaigns::services(cfg);
    export::services(cfg);
}

#[actix_web_codegen_const_routes::get(path = "PAGES.panel.home")]
pub async fn home(ctx: AppData) -> impl Responder {
    let loc = PAGES
        .panel
        .campaigns
        .get_about_route(&ctx.settings.default_campaign);

    HttpResponse::Found()
        .insert_header((http::header::LOCATION, loc))
        .finish()
}
