// Copyright (C) 2021  Aravinth Manivannan <realaravinth@batsense.net>
// SPDX-FileCopyrightText: 2023 Aravinth Manivannan <realaravinth@batsense.net>
//
// SPDX-License-Identifier: AGPL-3.0-or-later

use actix_auth_middleware::GetLoginRoute;
use serde::{Deserialize, Serialize};

use super::auth::routes::Auth;
use super::panel::routes::Panel;
pub const PAGES: Routes = Routes::new();

#[derive(Debug, Serialize, Deserialize, PartialEq, Eq, Clone)]
pub struct Routes {
    pub home: &'static str,
    pub auth: Auth,
    pub panel: Panel,
    pub about: &'static str,
    pub sitemap: &'static str,
    pub thanks: &'static str,
    pub donate: &'static str,
    pub security: &'static str,
    pub privacy: &'static str,
}

impl Routes {
    const fn new() -> Routes {
        let panel = Panel::new();
        let home = panel.home;
        Routes {
            auth: Auth::new(),
            panel,
            home,
            about: "https://mcaptcha.org/about/",
            sitemap: "/sitemap.xml",
            thanks: "https://mcaptcha.org/thanks",
            donate: "https://mcaptcha.org/donate",
            security: "https://mcaptcha.org/security",
            privacy: "https://mcaptcha.org/privacy-policy/",
        }
    }

    pub const fn get_sitemap() -> [&'static str; 3] {
        let a = Auth::get_sitemap();
        let p = Panel::get_sitemap();
        [a[0], a[1], p[0]] //, p[1], p[2], p[3], p[4]]
    }
}

impl GetLoginRoute for Routes {
    fn get_login_route(&self, src: Option<&str>) -> String {
        if let Some(redirect_to) = src {
            //                uri::Builder::new().path_and_query(
            format!(
                "{}?redirect_to={}",
                self.auth.join,
                urlencoding::encode(redirect_to)
            )
        //                let mut url: Uri = self.register.parse().unwrap();
        //                url.qu
        //                url.query_pairs_mut()
        //                    .append_pair("redirect_to", redirect_to);
        } else {
            self.auth.join.to_string()
        }
    }
}

#[cfg(test)]
mod tests {
    use super::*;

    #[test]
    fn sitemap_works() {
        Routes::get_sitemap();
    }
}
